@@ -18,12 +18,11 @@ class MongoDS(BaseDS):
         else:
             return col.insert(data)
 
-    def get(self, id):
+    def get(self, _id):
         return self.conn.db.find({"_id": _id})
 
-    def delete(self, id):
-        self.conn.db.remove({"_id": _id})
-
+    def remove(self, kind, fltr):
+        self.conn.db[kind].remove(fltr)
     def save_multi(self, ids=[]):
         pass
 
